@@ -4,6 +4,7 @@ from lftk.derivation.avgentity   import AvgEntity
 from lftk.derivation.typetokenratio import TypeTokenRatio
 from lftk.derivation.avgpartofspeech import AvgPartOfSpeech
 from lftk.derivation.readformula import ReadFormula
+from lftk.derivation.readtimeformula import ReadTimeFormula
 
-class DerivationCollector(AvgWordSent, AvgWordDiff, AvgEntity, TypeTokenRatio, AvgPartOfSpeech, ReadFormula):
+class DerivationCollector(AvgWordSent, AvgWordDiff, AvgEntity, TypeTokenRatio, AvgPartOfSpeech, ReadFormula, ReadTimeFormula):
     pass 
\ No newline at end of file
